@@ -52,7 +52,11 @@ int getrandom(WORD08 *out,WORD32 len,VPN *anchor)
 
 	/* read random data, handle errors */
 
-	if(read(fd,out,len)!=len)RETURN("read",0);
+	if(read(fd,out,len)!=len)
+	{
+		close(fd);
+		RET("read",0);
+	}
 
 	/* close random device */
 
@@ -1507,8 +1511,8 @@ int cryptosetup(VPN *anchor)
 
 	/* convert local and remote ip to numbers */
 
-	src=(WORD32)ntohl(inet_addr(anchor->local_ip));
-	dst=(WORD32)ntohl(inet_addr(anchor->remote_ip));
+	src=(WORD32)ntohl(getaddr(anchor->local_ip));
+	dst=(WORD32)ntohl(getaddr(anchor->remote_ip));
 
 	/* copy local and remote ips to initial key according to client
 	   or server mode */
