@@ -324,11 +324,11 @@ int chkip(char *ip)
 {
 	/* error, if given string is too long to hold valid ip */
 
-	if(strlen(ip)>15)return 0;
+	if(!dns&&strlen(ip)>15)return 0;
 
 	/* success, if conversion to ip succeeds */
 
-	if(inet_addr(ip)!=-1)return 1;
+	if(getaddr(ip)!=-1)return 1;
 
 	/* error, if not special case */
 
@@ -363,7 +363,10 @@ int chksvrcln(char mode,char *p1,char *p2,char *txt,VPN *anchor)
 		/* check server ip */
 
 		if(chkip(p1))
-			strcpy(mode?anchor->client_ip:anchor->server_ip,p1);
+		{
+			if(mode)anchor->client_ip=p1;
+			else anchor->server_ip=p1;
+		}
 		else
 		{
 			printf("Illegal %s ip.\n",txt);
@@ -568,7 +571,7 @@ int parse(VPN *anchor)
 
 	/* check local command ip */
 
-	if(chkip(CFG_LOCAL(p1)))strcpy(anchor->local_ip,CFG_LOCAL(p1));
+	if(chkip(CFG_LOCAL(p1)))anchor->local_ip=CFG_LOCAL(p1);
 	else
 	{
 		printf("Illegal local ip.\n");
@@ -577,7 +580,7 @@ int parse(VPN *anchor)
 
 	/* check remote command ip */
 
-	if(chkip(CFG_REMOTE(p1)))strcpy(anchor->remote_ip,CFG_REMOTE(p1));
+	if(chkip(CFG_REMOTE(p1)))anchor->remote_ip=CFG_REMOTE(p1);
 	else
 	{
 		printf("Illegal remote ip.\n");
@@ -709,11 +712,11 @@ int parse(VPN *anchor)
 				"for '%s' command.\n",config[i].item);
 			return 0;
 		}
-		anchor->rtab[anchor->rmax][0]=inet_addr(CFG_ROUTE(i,p1));
+		anchor->rtab[anchor->rmax][0]=getaddr(CFG_ROUTE(i,p1));
 		anchor->rtab[anchor->rmax][1]=
 			strcmp(CFG_ROUTE(i,p2),ip255)?
-				inet_addr(CFG_ROUTE(i,p2)):-1;
-		anchor->rtab[anchor->rmax][2]=inet_addr(CFG_ROUTE(i,p3));
+				getaddr(CFG_ROUTE(i,p2)):-1;
+		anchor->rtab[anchor->rmax][2]=getaddr(CFG_ROUTE(i,p3));
 		anchor->rmax++;
 	}
 
@@ -794,8 +797,8 @@ int parse(VPN *anchor)
 		/* in client mode peer is server ip,
 		   in server mode peer is client ip */
 
-		if(anchor->mode)anchor->peerip=inet_addr(anchor->server_ip);
-		else anchor->peerip=inet_addr(anchor->client_ip);
+		if(anchor->mode)anchor->peerip=getaddr(anchor->server_ip);
+		else anchor->peerip=getaddr(anchor->client_ip);
 
 		/* if a fixed device is given */
 
@@ -821,17 +824,22 @@ int parse(VPN *anchor)
 		}
 	}
 
-	/* check key file permissions and size, set extended mode */
+	/* if encryption has to be used */
 
-	switch(checkfile(anchor->keyfile,0377))
+	if(anchor->keysize)
 	{
-	case BLOWFISH_MAXKEY:	anchor->extended=0;
-				break;
-	case XKEYSIZE:		anchor->extended=1;
-				break;
-	default:		printf("'%s' has wrong size.\n",
-					anchor->keyfile);
-	case 0:			return 0;
+		/* check key file permissions and size, set extended mode */
+
+		switch(checkfile(anchor->keyfile,0377))
+		{
+		case BLOWFISH_MAXKEY:	anchor->extended=0;
+					break;
+		case XKEYSIZE:		anchor->extended=1;
+					break;
+		default:		printf("'%s' has wrong size.\n",
+						anchor->keyfile);
+		case 0:			return 0;
+		}
 	}
 
 	/* check that passphrase is given only for extended mode
